@@ -1,13 +1,10 @@
-{-# LANGUAGE OverloadedStrings #-}
 {-# LANGUAGE CPP #-}
+{-# LANGUAGE OverloadedStrings #-}
 
 module Program.Mighty.Process (
     getMightyPid
   ) where
 
-#if __GLASGOW_HASKELL__ < 709
-import Control.Applicative
-#endif
 import Control.Monad.Trans.Resource (runResourceT)
 import Data.ByteString.Char8 (ByteString)
 import qualified Data.ByteString.Char8 as BS
@@ -17,7 +14,6 @@ import qualified Data.Conduit.List as CL
 import Data.Conduit.Process
 import Data.Function
 import Data.List
-import Data.Ord
 import System.Posix.Types
 
 ----------------------------------------------------------------
@@ -65,7 +61,7 @@ findParent ps = deleteAloneChild $ masters ++ candidates
     candidates = map head
                $ filter (\xs -> length xs == 1) -- master is alone
                $ groupBy ((==) `on` ppid)
-               $ sortBy (comparing ppid) rest
+               $ sortOn ppid rest
 
 
 deleteAloneChild :: [PsResult] -> [PsResult]
@@ -79,7 +75,7 @@ deleteAloneChild (p:ps) = p : deleteAloneChild (filter noParent ps)
 
 -- | Getting the process id of a running Mighty.
 getMightyPid :: IO [ProcessID]
-getMightyPid = (map pid . findParent) <$> runPS
+getMightyPid = map pid . findParent <$> runPS
 
 ----------------------------------------------------------------
 
