@@ -1,5 +1,6 @@
-{-# LANGUAGE OverloadedStrings, TupleSections #-}
 {-# LANGUAGE CPP #-}
+{-# LANGUAGE OverloadedStrings #-}
+{-# LANGUAGE TupleSections #-}
 
 module Program.Mighty.Route (
   -- * Paring a routing file
@@ -19,13 +20,13 @@ module Program.Mighty.Route (
   , writeRouteDBRef
   ) where
 
-#if __GLASGOW_HASKELL__ < 709
-import Control.Applicative hiding (many,(<|>))
-#endif
 import Control.Monad
 import Data.ByteString
 import qualified Data.ByteString.Char8 as BS
 import Data.IORef
+#ifdef DHALL
+import GHC.Natural (Natural)
+#endif
 import Network.Wai.Application.Classic
 import Text.Parsec
 import Text.Parsec.ByteString.Lazy
@@ -39,7 +40,12 @@ type Src      = Path
 -- | A physical path in a file system.
 type Dst      = Path
 type Domain   = ByteString
+#ifdef DHALL
+type Port     = Natural
+#else
 type Port     = Int
+#endif
+
 data Block    = Block [Domain] [Route] deriving (Eq,Show)
 data Route    = RouteFile     Src Dst
               | RouteRedirect Src Dst
