@@ -7,6 +7,7 @@ module Server (server, defaultDomain, defaultPort) where
 import Control.Concurrent (runInUnboundThread)
 import Control.Exception (try)
 import Control.Monad (unless, when)
+import Data.Either (fromRight)
 import qualified Data.ByteString.Char8 as BS
 import Data.Streaming.Network (bindPortTCP)
 import qualified Network.HTTP.Client as H
@@ -24,8 +25,6 @@ import qualified System.TimeManager as T
 import Program.Mighty
 import WaiApp
 
-import qualified Network.Wai.Middleware.Push.Referer as P
-
 #ifdef HTTP_OVER_TLS
 import Control.Concurrent.Async (concurrently_)
 import Data.Char (isSpace)
@@ -158,7 +157,7 @@ loadCredentials opt = do
     cert   <- BS.readFile $ opt_tls_cert_file opt
     chains <- mapM BS.readFile chain_files
     key    <- BS.readFile $ opt_tls_key_file opt
-    let Right cred = TLS.credentialLoadX509ChainFromMemory cert chains key
+    let cred = fromRight (error "loadCredentials") $ TLS.credentialLoadX509ChainFromMemory cert chains key
     return $ Credentials [cred]
   where
     strip = dropWhileEnd isSpace . dropWhile isSpace
@@ -198,6 +197,7 @@ mighty opt rpt svc lgr pushlgr mgr rdr _mcreds _msmgr tmgr
     QUIC s1 s2 -> do
         let quicPort' = BS.pack $ show quicPort
             strver Q.Version1 = ""
+            strver Q.Version2 = ""
             strver v = BS.append "-" $ BS.pack $ show $ fromVersion v
             quicDrafts = map strver quicVersions
             value v = BS.concat ["h3",v,"=\":",quicPort',"\""]
@@ -214,7 +214,7 @@ mighty opt rpt svc lgr pushlgr mgr rdr _mcreds _msmgr tmgr
     _ -> error "never reach"
 #endif
   where
-    app = P.pushOnReferer P.defaultSettings $ fileCgiApp cspec filespec cgispec revproxyspec rdr
+    app = fileCgiApp cspec filespec cgispec revproxyspec rdr
     debug = opt_debug_mode opt
     -- We don't use setInstallShutdownHandler because we may use
     -- two sockets for HTTP and HTTPS.
@@ -232,6 +232,7 @@ mighty opt rpt svc lgr pushlgr mgr rdr _mcreds _msmgr tmgr
     tlsSetting = defaultTlsSettings {
         tlsCredentials    = _mcreds
       , tlsSessionManager = _msmgr
+      , tlsAllowedVersions = [TLS.TLS13,TLS.TLS12]
       }
 #endif
     serverName = BS.pack $ opt_server_name opt
@@ -270,8 +271,10 @@ chooseALPN ver protos = case find (\x -> x == h3 || x == hq) protos of
   Just proto -> return proto
   where
     h3 | ver == Q.Version1 = "h3"
+       | ver == Q.Version2 = "h3"
        | otherwise = "h3-" `BS.append` BS.pack (show (fromVersion ver))
     hq | ver == Q.Version1 = "hq-interop"
+       | ver == Q.Version2 = "hq-interop"
        | otherwise = "hq-" `BS.append` BS.pack (show (fromVersion ver))
 
 fromVersion :: Q.Version -> Int
